==> easy_onvif-2.1.0-dev.8.tar.gz: lib/shared.dart <==
/// classes shared by other libraries
library shared;

export 'src/model/common/audio_encoder_configuration.dart';
export 'src/model/common/audio_source_configuration.dart';
export 'src/model/common/backlight_compensation.dart';
export 'src/model/common/event.dart';
export 'src/model/common/exposure.dart';
export 'src/model/common/focus.dart';
export 'src/model/common/get_metadata_configuration_options_response.dart';
export 'src/model/common/get_metadata_configurations_response.dart';
export 'src/model/common/h264.dart';
export 'src/model/common/int_rectangle.dart';
export 'src/model/common/imaging.dart';
export 'src/model/common/ip_address.dart';
export 'src/model/common/metadata_configuration_options_extension.dart';
export 'src/model/common/metadata_configuration_options.dart';
export 'src/model/common/metadata_configuration.dart';
export 'src/model/common/mpeg4.dart';
export 'src/model/common/multicast_configuration.dart';
export 'src/model/common/pan_tilt_limits.dart';
export 'src/model/common/pan_tilt.dart';
export 'src/model/common/ptz_configuration.dart';
export 'src/model/common/ptz_filter.dart';
export 'src/model/common/ptz_speed.dart';
export 'src/model/common/ptz_status_filter_options.dart';
export 'src/model/common/rate_control.dart';
export 'src/model/common/resolution.dart';
export 'src/model/common/space.dart';
export 'src/model/common/space1d.dart';
export 'src/model/common/space2d.dart';
export 'src/model/common/video_analytics_configuration.dart';
export 'src/model/common/video_encoder_configuration.dart';
export 'src/model/common/video_source_configuration.dart';
export 'src/model/common/white_balance.dart';
export 'src/model/common/wide_dynamic_range.dart';
export 'src/model/common/window.dart';
export 'src/model/common/zoom_limits.dart';
export 'src/model/common/zoom.dart';

==> easy_onvif-3.0.0-dev.0.tar.gz: lib/shared.dart <==
/// classes shared by other libraries
library shared;

export 'src/model/common/audio_encoder_configuration.dart';
export 'src/model/common/audio_source_configuration.dart';
export 'src/model/common/backlight_compensation.dart';
export 'src/model/common/event.dart';
export 'src/model/common/exposure.dart';
export 'src/model/common/float_range.dart';
export 'src/model/common/focus.dart';
export 'src/model/common/get_metadata_configuration_options_response.dart';
export 'src/model/common/get_metadata_configurations_response.dart';
export 'src/model/common/h264.dart';
export 'src/model/common/int_range.dart';
export 'src/model/common/int_rectangle.dart';
export 'src/model/common/int_rectangle_range.dart';
export 'src/model/common/imaging.dart';
export 'src/model/common/ip_address.dart';
export 'src/model/common/metadata_configuration_options_extension.dart';
export 'src/model/common/metadata_configuration_options.dart';
export 'src/model/common/metadata_configuration.dart';
export 'src/model/common/mixed_profile.dart';
export 'src/model/common/mpeg4.dart';
export 'src/model/common/multicast_configuration.dart';
export 'src/model/common/pan_tilt_limits.dart';
export 'src/model/common/ptz_configuration.dart';
export 'src/model/common/ptz_filter.dart';
export 'src/model/common/ptz_speed.dart';
export 'src/model/common/ptz_status.dart';
export 'src/model/common/ptz_status_filter_options.dart';
export 'src/model/common/ptz_vector.dart';
export 'src/model/common/reference_token.dart';
export 'src/model/common/rate_control.dart';
export 'src/model/common/resolution.dart';
export 'src/model/common/space_1d.dart';
export 'src/model/common/space_2d.dart';
export 'src/model/common/vector_1d.dart';
export 'src/model/common/vector_2d.dart';
export 'src/model/common/video_analytics_configuration.dart';
export 'src/model/common/video_encoder_configuration.dart';
export 'src/model/common/video_source_configuration.dart';
export 'src/model/common/white_balance.dart';
export 'src/model/common/wide_dynamic_range.dart';
export 'src/model/common/window.dart';
export 'src/model/common/xml_serializable.dart';
export 'src/model/common/zoom_limits.dart';
